@@ -2,17 +2,22 @@ from __future__ import unicode_literals
 
 from datetime import datetime
 from tkinter.messagebox import showerror, askokcancel
+from multiprocessing import Pipe
 from tkinter import *
 from threading import Lock, Thread
 
 import os
 import logging
+import sys
+import string
 
 
 class LogHandle(object):
     __file_dir = None
     __base_name = None
     __gui_console = None
+    __write_pipe = None
+    __read_pipe = None
 
     """
     Logging that becomes easier and more uniformed
@@ -28,6 +33,15 @@ class LogHandle(object):
 
         self.file_dir = file_dir
         self.base_name = base_name
+        self.__write_pipe, self.__read_pipe = Pipe()
+        self.__printable = set(string.printable)
+        p = Thread(target=self.__pipe_listen)
+        p.daemon = True
+        p.start()
+
+    @property
+    def write_pipe(self):
+        return self.__write_pipe
 
     @property
     def file_dir(self):
@@ -66,7 +80,36 @@ class LogHandle(object):
         for handler in logging.root.handlers[:]:
             logging.root.removeHandler(handler)
 
+    def __pipe_listen(self):
+        while True:
+            args = self.__read_pipe.recv()
+
+            if isinstance(args, dict) and 'command' in args.keys():
+                command = args['command']
+                del args['command']
+
+                if command == 'gui_console':
+                    self.__gui_console_set(**args)
+                elif command == 'write_to_log':
+                    self.__write_to_log(**args)
+            elif isinstance(args, list) and len(args) > 1:
+                command = args[0]
+                args.remove(args[0])
+
+                if command == 'gui_console':
+                    self.__gui_console_set(*args)
+                elif command == 'write_to_log':
+                    self.__write_to_log(*args)
+
     def gui_console(self, title=None, destroy=False, turn_off=False, gui_obj=None):
+        self.__write_pipe.send({'command': 'gui_console','title': title, 'destroy': destroy, 'turn_off': turn_off,
+                                'gui_obj': gui_obj})
+
+    def write_to_log(self, message, action='info', print_only=False):
+        self.__write_pipe.send({'command': 'write_to_log', 'message': message, 'action': action,
+                                'print_only': print_only})
+
+    def __gui_console_set(self, title=None, destroy=False, turn_off=False, gui_obj=None, *args, **kwargs):
         if self.__gui_console and destroy:
             self.__gui_console.destroy()
             self.__gui_console = None
@@ -78,7 +121,7 @@ class LogHandle(object):
         else:
             self.__gui_console = GUIConsole(parent=self, title=title)
 
-    def write_to_log(self, message, action='info', print_only=False):
+    def __write_to_log(self, message, action='info', print_only=False, *args, **kwargs):
         """
         Logging becomes more organized!
 
@@ -99,6 +142,8 @@ class LogHandle(object):
             logging.basicConfig(filename=filepath,
                                 level=logging.DEBUG, format=' %(asctime)s - %(levelname)s - %(message)s')
 
+        message = ''.join(filter(lambda x: x in self.__printable, message))
+
         if self.__gui_console:
             self.__gui_console.print_gui('{0} - {1} - {2}'.format(datetime.now().__format__("%Y%m%d %I:%M:%S %p"),
                                                                   action.upper(), message))
